@@ -1,21 +1,8 @@
 /*
-  Copyright (c) 2010 Bertjan Broeksema <broeksema@kde.org>
-  Copyright (C) 2010 Klaralvdalens Datakonsult AB, a KDAB Group company <info@kdab.net>
+  SPDX-FileCopyrightText: 2010 Bertjan Broeksema <broeksema@kde.org>
+  SPDX-FileCopyrightText: 2010 Klaralvdalens Datakonsult AB, a KDAB Group company <info@kdab.net>
 
-  This library is free software; you can redistribute it and/or modify it
-  under the terms of the GNU Library General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or (at your
-  option) any later version.
-
-  This library is distributed in the hope that it will be useful, but WITHOUT
-  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-  License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to the
-  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-  02110-1301, USA.
+  SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "alarmdialog.h"
@@ -24,9 +11,9 @@
 
 #include <KEmailAddress>
 #include <KLocalizedString>
-#include <QVBoxLayout>
 #include <QDialogButtonBox>
 #include <QPushButton>
+#include <QVBoxLayout>
 
 using namespace IncidenceEditorNG;
 
@@ -34,20 +21,17 @@ AlarmDialog::AlarmDialog(KCalendarCore::Incidence::IncidenceType incidenceType,
     : QDialog(parent)
     , mUi(new Ui::AlarmDialog)
     , mIncidenceType(incidenceType)
-    , mAllowBeginReminders(true)
-    , mAllowEndReminders(true)
 {
     setWindowTitle(i18nc("@title:window", "Create a new reminder"));
-    QVBoxLayout *mainLayout = new QVBoxLayout(this);
-    QDialogButtonBox *buttonBox = new QDialogButtonBox(
-        QDialogButtonBox::Ok | QDialogButtonBox::Cancel, this);
+    auto mainLayout = new QVBoxLayout(this);
+    auto buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, this);
     QPushButton *okButton = buttonBox->button(QDialogButtonBox::Ok);
     okButton->setDefault(true);
     okButton->setShortcut(Qt::CTRL | Qt::Key_Return);
     connect(buttonBox, &QDialogButtonBox::accepted, this, &AlarmDialog::accept);
     connect(buttonBox, &QDialogButtonBox::rejected, this, &AlarmDialog::reject);
 
-    QWidget *mainWidget = new QWidget(this);
+    auto mainWidget = new QWidget(this);
     mUi->setupUi(mainWidget);
     mainLayout->addWidget(mainWidget);
     mainLayout->addWidget(buttonBox);
@@ -105,10 +89,10 @@ void AlarmDialog::load(const KCalendarCore::Alarm::Ptr &alarm)
     offset = offset / 60; // make minutes
     int useoffset = offset;
 
-    if (offset % (24 * 60) == 0 && offset > 0) {     // divides evenly into days?
+    if (offset % (24 * 60) == 0 && offset > 0) { // divides evenly into days?
         useoffset = offset / (24 * 60);
         mUi->mOffsetUnit->setCurrentIndex(2);
-    } else if (offset % 60 == 0 && offset > 0) {   // divides evenly into hours?
+    } else if (offset % 60 == 0 && offset > 0) { // divides evenly into hours?
         useoffset = offset / 60;
         mUi->mOffsetUnit->setCurrentIndex(1);
     } else {
@@ -121,7 +105,7 @@ void AlarmDialog::load(const KCalendarCore::Alarm::Ptr &alarm)
     mUi->mRepeats->setChecked(alarm->repeatCount() > 0);
     if (alarm->repeatCount() > 0) {
         mUi->mRepeatCount->setValue(alarm->repeatCount());
-        mUi->mRepeatInterval->setValue(alarm->snoozeTime().asSeconds() / 60);   // show as minutes
+        mUi->mRepeatInterval->setValue(alarm->snoozeTime().asSeconds() / 60); // show as minutes
     }
     int id = 0;
 
@@ -131,28 +115,8 @@ void AlarmDialog::load(const KCalendarCore::Alarm::Ptr &alarm)
         mUi->mSoundFile->setUrl(QUrl::fromLocalFile(alarm->audioFile()));
         id = 1;
         break;
-    case KCalendarCore::Alarm::Procedure:
-        mUi->mTypeCombo->setCurrentIndex(2);
-        mUi->mApplication->setUrl(QUrl::fromLocalFile(alarm->programFile()));
-        mUi->mAppArguments->setText(alarm->programArguments());
-        id = 2;
-        break;
     case KCalendarCore::Alarm::Email:
-    {
-        mUi->mTypeCombo->setCurrentIndex(3);
-        KCalendarCore::Person::List addresses = alarm->mailAddresses();
-        QStringList add;
-        add.reserve(addresses.count());
-        const KCalendarCore::Person::List::ConstIterator end(addresses.constEnd());
-        for (KCalendarCore::Person::List::ConstIterator it = addresses.constBegin();
-             it != end; ++it) {
-            add << (*it).fullName();
-        }
-        mUi->mEmailAddress->setText(add.join(QLatin1String(", ")));
-        mUi->mEmailText->setPlainText(alarm->mailText());
-        id = 3;
-        break;
-    }
+    case KCalendarCore::Alarm::Procedure:
     case KCalendarCore::Alarm::Display:
     case KCalendarCore::Alarm::Invalid:
     default:
@@ -162,8 +126,7 @@ void AlarmDialog::load(const KCalendarCore::Alarm::Ptr &alarm)
     }
 
     mUi->mTypeStack->setCurrentIndex(id);
-    if (alarm->audioFile().isEmpty()
-        && IncidenceEditorNG::EditorConfig::instance()->defaultAudioFileReminders()) {
+    if (alarm->audioFile().isEmpty() && IncidenceEditorNG::EditorConfig::instance()->defaultAudioFileReminders()) {
         mUi->mSoundFile->setUrl(IncidenceEditorNG::EditorConfig::instance()->audioFilePath());
     }
 }
@@ -184,7 +147,7 @@ void AlarmDialog::save(const KCalendarCore::Alarm::Ptr &alarm) const
     }
 
     const int beforeafterpos = mUi->mBeforeAfter->currentIndex();
-    if (beforeafterpos % 2 == 0) {   // before -> negative
+    if (beforeafterpos % 2 == 0) { // before -> negative
         offset = -offset;
     }
 
@@ -196,36 +159,24 @@ void AlarmDialog::save(const KCalendarCore::Alarm::Ptr &alarm) const
 
     // We assume that if mAllowBeginReminders is not set, that mAllowBeginReminders
     // is set.
-    if (!mAllowBeginReminders) {   // before or after DTDUE
+    if (!mAllowBeginReminders) { // before or after DTDUE
         alarm->setEndOffset(KCalendarCore::Duration(offset));
-    } else if (beforeafterpos == 0 || beforeafterpos == 1) {   // before or after DTSTART
+    } else if (beforeafterpos == 0 || beforeafterpos == 1) { // before or after DTSTART
         alarm->setStartOffset(KCalendarCore::Duration(offset));
-    } else if (beforeafterpos == 2 || beforeafterpos == 3) {  // before or after DTEND/DTDUE
+    } else if (beforeafterpos == 2 || beforeafterpos == 3) { // before or after DTEND/DTDUE
         alarm->setEndOffset(KCalendarCore::Duration(offset));
     }
 
     // Repeating
     if (mUi->mRepeats->isChecked()) {
         alarm->setRepeatCount(mUi->mRepeatCount->value());
-        alarm->setSnoozeTime(mUi->mRepeatInterval->value() * 60);   // convert back to seconds
+        alarm->setSnoozeTime(mUi->mRepeatInterval->value() * 60); // convert back to seconds
     } else {
         alarm->setRepeatCount(0);
     }
 
-    if (mUi->mTypeCombo->currentIndex() == 1) {   // Audio
+    if (mUi->mTypeCombo->currentIndex() == 1) { // Audio
         alarm->setAudioAlarm(mUi->mSoundFile->url().toLocalFile());
-    } else if (mUi->mTypeCombo->currentIndex() == 2) {   // Application / script
-        alarm->setProcedureAlarm(mUi->mApplication->url().toLocalFile(),
-                                 mUi->mAppArguments->text());
-    } else if (mUi->mTypeCombo->currentIndex() == 3) {   // Email
-        QStringList addresses = KEmailAddress::splitAddressList(mUi->mEmailAddress->text());
-        KCalendarCore::Person::List add;
-        add.reserve(addresses.count());
-        for (QStringList::Iterator it = addresses.begin(), end = addresses.end(); it != end; ++it) {
-            add << KCalendarCore::Person::fromFullName(*it);
-        }
-        // TODO: Add a subject line and possibilities for attachments
-        alarm->setEmailAlarm(QString(), mUi->mEmailText->toPlainText(), add);
     } else { // Display
         alarm->setDisplayAlarm(mUi->mDisplayText->toPlainText());
     }
